# -*- coding:utf-8 -*-
import os, ctypes, getpass
from security_module import SecurityModule

from utils import check_user, check_group, check_login, enable_user, disable_user, create_file, create_symbolic, unlink_symbolic
from log import log_error, log_debug


DATA_DIR="/usr/share/security-switch/data"
POLKIT_DEST="/etc/polkit-1/localauthority/10-vendor.d"
POLKIT_SRC=DATA_DIR+"/polkit"
POLKIT_CONF="kysec.pkla"
LIGHTDM_DEST="/usr/share/lightdm/lightdm.conf.d"
LIGHTDM_SRC=DATA_DIR+"/lightdm"
LIGHTDM_CONF="99-enable-manual-login.conf"

class Admin3Module(SecurityModule):
	status_desc={ "0": "关闭", "1": "启用" }
	def __init__(self, auto_reset = False):
		SecurityModule.__init__(self, "admin3")
		self.auto_resetpw = auto_reset

	@staticmethod
	def getstatus():
		try:
			kyseclib = ctypes.cdll.LoadLibrary("libkysec.so.0")
		except OSError as e:
			return 0	
		else:
			return kyseclib.kysec_get_func_status(3)

	@classmethod
	def check_system(self, next_state):
		if next_state:
			src_file = POLKIT_SRC+"/"+POLKIT_CONF
			log_debug("检查'%s'是否存在..."%src_file)
			if not os.path.exists(src_file):
				return (False, "Polkit配置文件 '%s' 不存在"%src_file)

			'''
			src_file=LIGHTDM_SRC+"/"+LIGHTDM_CONF
			log_debug("检查'%s'是否存在..."%src_file)
			if not os.path.exists(src_file):
				return (False, "Lightdm配置文件 '%s' 不存在"%src_file)
			'''

			log_debug("检查用户组secadm的GID是否为600...")
			result, error=check_group("secadm", 600)	
			if not result:
				return (False, error)

			log_debug("检查用户组auditadm的GID是否为700...")
			result, error=check_group("auditadm", 700)	
			if not result:
				return (False, error)

			log_debug("检查用户secadm是否合法...")
			result, error=check_user("secadm", 600, "/home/secadm", ["secadm"])
			if not result:
				return (False, error)

			log_debug("检查用户auditadm是否合法...")
			#result, error=check_user("auditadm", 700, "/home/auditadm", ["auditadm", "syslog", "adm"])
			result, error=check_user("auditadm", 700, "/home/auditadm", ["auditadm", "adm"])
			if not result:
				return (False, error)

		return (True, None)

	def do_enable(self):
		if not self.getstatus():
			log_debug("启用root账户...")
			result, error=enable_user("root", auto_reset = self.auto_resetpw)
			if not result:
				return (False, "无法启用root账户: %s"%error)

			log_debug("启用secadm账户...")
			result, error=enable_user("secadm", auto_reset = self.auto_resetpw)
			if not result:
				return (False, "无法启用secadm账户: %s"%error)

			log_debug("启用auditadm账户...")
			result, error=enable_user("auditadm", auto_reset = self.auto_resetpw)
			if not result:
				return (False, "无法启用auditadm账户: %s"%error)
		else:
			log_debug("三权分立已启用，跳过密码重置过程")

		try:
			log_debug("启用Polkit配置...")
			create_symbolic(POLKIT_SRC+"/"+POLKIT_CONF, POLKIT_DEST+"/"+POLKIT_CONF)
		except Exception as e:
			log_error("Failed to update polkit configuration: %s"%str(e))
			return (False, "更新polkit配置时出错: %s"%str(e))
		'''
		try:
			log_debug("启用Lightdm配置...")
			create_symbolic(LIGHTDM_SRC+"/"+LIGHTDM_CONF, LIGHTDM_DEST+"/"+LIGHTDM_CONF)
		except Exception as e:
			log_error("Failed to update lightdm configuration: %s"%str(e))
			return (False, "更新Lightdm配置时出错: %s"%str(e))
		'''

		log_debug("创建文件 /.exectl ...")
		result, error = create_file("/.exectl")
		if not result:
			return (False, "无法创建重打标记文件")

		return (True, None)

	@classmethod
	def do_disable(self):
		try:
			log_debug("禁用Polkit配置...")
			unlink_symbolic(POLKIT_DEST+"/"+POLKIT_CONF)
		except Exception as e:
			log_error("Failed to update polkit configuration: %s"%str(e))
			return (False, "更新Polkit配置时出错: %s\n"%str(e))
		'''
		try:
			log_debug("禁用Lightdm配置...")
			unlink_symbolic(LIGHTDM_DEST+"/"+LIGHTDM_CONF)
		except Exception as e:
			log_error("Failed to update lightdm configuration: %s"%str(e))
			return (False, "更新Lightdm配置时出错: %s"%str(e))
		'''

		return (True, None)

